@@ -7,6 +7,7 @@
 #' @param fileName character: the name of the file (with no extension)
 #' @param where character: the name of the web repository
 #' @param type character: the extension of the web file
+#' @param fileEncoding character: declares the encoding used on a file, deafults to "UTF-8-BOM"
 #'
 #' @return returns a data.frame
 #' @author Andrea Onofri
@@ -16,7 +17,8 @@
 #'
 getAgroData <- function(fileName,
                         where = "https://www.casaonofri.it/_datasets/",
-                        type = "csv") {
+                        type = "csv",
+                        fileEncoding = "UTF-8-BOM") {
   fileName <- paste(where, fileName, ".", type, sep = "")
   read.csv(fileName)
 }
